##  Overview
Once you have determined the scope of the data you want to import and mapped your existing data to the SAP LeanIX data model, your next step is to bring the data into your SAP LeanIX workspace.
To start with and to ensure a meaningful assessment, focus on Application, Business Capability, and Organization Fact Sheets. We recommend to begin by getting application data into the workspace. Next, define and add business capabilities and outline your organizational structure and hierarchy. Then, link applications to business capabilities and organizations. The next section provides additional details on accomplishing these steps.
There are several ways in which you can get data into SAP LeanIX; here is an overview:
  * Out-of-the-box integration and discovery features: SAP LeanIX offers various integrations and discovery features to quickly bring in data from multiple systems and to automatically keep the data up-to-date. To learn more about all available integration and discovery features, see [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how SAP LeanIX integrates with various systems, automates data syncing, enhances collaboration, and provides the reference catalog to ensure accurate and up-to-date information in your workspace.").
  * Inventory builder: Inventory builder uses AI to extract architectural elements from diagrams and images, automatically creating fact sheets and relationships. This speeds up inventory creation, simplifies maintenance, and accelerates adoption by turning unstructured data into structured insights. For a detailed guide, see [Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory builder uses AI to analyze diagrams, images, and text-based files. It extracts fact sheets and relations to help you build your inventory faster. You can review, adjust, and create fact sheets from discovered data.").
  * Via the Excel Import/Export function: This is the most common approach for bringing data into your workspace, especially when starting out. If your organization has pre-collated enterprise architecture data, you can easily import or edit bulk data using an Excel file. For detailed instructions, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
  * Add data manually: In the manual method, you create and add data to Fact Sheets individually in the Inventory. Find the detailed guide here: [Adding and Editing Data in Fact Sheets](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Users with the appropriate permissions can add and edit data in fact sheets, while administrators can customize and manage these permissions. By switching to table view in the inventory, you can perform inline editing across multiple fact sheets, and using the import option, you can update multiple fact sheets in bulk.").
  * Via Surveys: You can crowdsource data through surveys. By including Fact Sheet elements in the Surveys, the responses received are directly updated in the Fact Sheets. You can find a detailed description of this function here: [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.").
